#!/bin/sh
#------------------------------------------------------------------------------
# /var/install/config.d/postgresql84-update.sh - parameter update script
#
# Creation   :  2005-09-11 dv
# Last Update:  $Id: postgresql96-update.sh 30 2018-07-08 16:58:57Z  $
#
# Copyright (c) 2018 the eisfair team, team(at)eisfair(dot)org
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#------------------------------------------------------------------------------

package='postgresql84'

#------------------------------------------------------------------------------
# include eisfair script library
#------------------------------------------------------------------------------

. /var/install/include/eislib
. /var/install/include/configlib


#------------------------------------------------------------------------------
# list of default values
#------------------------------------------------------------------------------

START_POSTGRESQL84='no'                      # Shall postgresql deamon be started

POSTGRESQL84_NETWORKING='yes'                # Enable network access to PostgreSQL
POSTGRESQL84_SERVER_PORT='5432'              # TCP/IP port for network access
POSTGRESQL84_MAX_CONNECTS='50'               # max concurrent connects

POSTGRESQL84_HOST_N='2'                      # number of host entries

POSTGRESQL84_HOST_1_TYPE='local'             # Local or network(host) access?
POSTGRESQL84_HOST_1_NETWORK=''               # IP-Address of host (or network) 1
POSTGRESQL84_HOST_1_USERAUTH='trust'         # Authentication
POSTGRESQL84_HOST_1_DATABASE='all'           # affected databases
POSTGRESQL84_HOST_1_USER='all'               # affected users

POSTGRESQL84_HOST_2_TYPE='host'              # Local or network(host) access?
POSTGRESQL84_HOST_2_NETWORK='127.0.0.1/32'   # IP-Address of host (or network) 1
POSTGRESQL84_HOST_2_USERAUTH='trust'         # Authentication
POSTGRESQL84_HOST_2_DATABASE='all'           # affected databases
POSTGRESQL84_HOST_2_USER='all'               # affected users

POSTGRESQL84_BACKUP_SCHEDULE='30 0 * * *'    # cron schedule for autom. backup
POSTGRESQL84_BACKUP_TARGET='/var/lib/pgsql_backup'
                                           # target directory for backups
POSTGRESQL84_BACKUP_N='0'                    # Number of databases to backup
POSTGRESQL84_BACKUP_1_DBNAME='template1'     # Name of database to backup
POSTGRESQL84_BACKUP_1_USER='postgres'        # User to connect to db server
POSTGRESQL84_BACKUP_1_MAX='7'                # Number of backup files to maintain
POSTGRESQL84_BACKUP_MOUNT=''                 # Command executed before backup
POSTGRESQL84_BACKUP_UMOUNT=''                # Command executed after backup
POSTGRESQL84_BACKUP_NOTIFY='root@localhost'  # E-mail address for error notification

POSTGRESQL84_AUTOVACUUM='yes'                # Start autovacuum process

# advanced options (resource truning)

POSTGRESQL84_RESOURCE_TUNING='no'
POSTGRESQL84_SHARED_MEM='16MB'               # size of shared memory block
POSTGRESQL84_WORK_MEM='1MB'                  # size of per session memory
POSTGRESQL84_TEMP_MEM='8MB'                  # size for temporary tables
POSTGRESQL84_MAINTAIN_MEM='8MB'              # size for maintainance tasks
POSTGRESQL84_PREP_TRANSACTIONS='5'           # max. number of prepared transactions

# advanced options (wal tuning)

POSTGRESQL84_WAL_TUNING='no'
POSTGRESQL84_FSYNC='yes'                     # switch fsync on or off
POSTGRESQL84_SYNC_METHOD='fsync'             # fsync, fdatasync, open_sync, open_datasync
#POSTGRESQL84_WAL_BUFFERS='8'                 # WAL buffers in memory, 8KB each
POSTGRESQL84_WAL_DATA_MEM='64kB'             # the amount of memory used for WAL data
POSTGRESQL84_COMMIT_DELAY='0'                # delay for writes on commits
POSTGRESQL84_COMMIT_SIBLINGS='5'             # number of concurrent commits to delay
POSTGRESQL84_CHECKPOINT_SECTIONS='3'         # number of sections before checkpoint
POSTGRESQL84_CHECKPOINT_TIMEOUT='300'        # 300 sec. timeout
POSTGRESQL84_CHECKPOINT_WARNING='30'         # default = 30, 0 = off

# advanced options (log options)

POSTGRESQL84_LOG_SETTINGS='no'
POSTGRESQL84_CLIENT_LOG_LEVEL='notice'      # log level for client programs
POSTGRESQL84_SERVER_LOG_LEVEL='notice'      # log level for server log
POSTGRESQL84_LOG_VERBOSE='no'               # verbose log messages
POSTGRESQL84_LOG_STATEMENTS='no'            # writes SQL statements to log


#------------------------------------------------------------------------------
# rename old variables
#------------------------------------------------------------------------------

rename_old_variables()
{
	# rename config of old package
	if [ -f /etc/config.d/postgresql ]
    then
        sed -e "s/POSTGRESQL_/POSTGRESQL84_/g" \
            -e "s/START_POSTGRESQL/START_POSTGRESQL84/g" \
            /etc/config.d/postgresql > /tmp/config$$

        mv /tmp/config$$ /etc/config.d/${package}
        rm -f /etc/config.d/postgresql
    fi

    # read old values
    if [ -f /etc/config.d/${package} ]
    then
        . /etc/config.d/${package}

        if [ "${POSTGRESQL84_RESOURCE_TUNING}" == 'yes' ]
        then
            if [ "${POSTGRESQL84_SHARED_BUFFERS}" != "" ]
            then
                POSTGRESQL84_SHARED_MEM="$[${POSTGRESQL84_SHARED_BUFFERS} * 8]kB"
            fi

            if [ "${POSTGRESQL84_TEMP_BUFFERS}" != "" ]
            then
                POSTGRESQL84_TEMP_MEM="$[${POSTGRESQL84_TEMP_BUFFERS} * 8]kB"
            fi
        fi

        if [ "${POSTGRESQL84_WAL_TUNING}" == 'yes' ]
        then
            if [ "${POSTGRESQL84_WAL_BUFFERS}" != "" ]
            then
                POSTGRESQL84_WAL_DATA_MEM="$[${POSTGRESQL84_WAL_BUFFERS} * 8]kB"
            fi
        fi
    fi
}


#------------------------------------------------------------------------------
# add new variables
#------------------------------------------------------------------------------

add_new_variables()
{
    # no variables added at this time
    echo "" > /dev/null
}


#------------------------------------------------------------------------------
# Write config and default files
#------------------------------------------------------------------------------

make_config_file()
{
    internal_conf_file=$1
    (
    printgpl -conf "$packages_name" "2006-12-16" "dv" \
         "2018 the eisfair team, team(at)eisfair(dot)org"

    printgroup "PostgreSQL server settings"
    printvar "START_POSTGRESQL84" "Shall PostgreSQL be started"

    printgroup "PostgreSQL network (TCP/IP) access"
    printvar "POSTGRESQL84_NETWORKING" "Enable network access to PostgreSQL"
    printvar "POSTGRESQL84_SERVER_PORT" "TCP/IP port for network access"
    printvar "POSTGRESQL84_MAX_CONNECTS" "Max concurrent connects"

    printgroup "Host access table"
    printvar "POSTGRESQL84_HOST_N" "Number of host entries"
    echo ""
    printvar "POSTGRESQL84_HOST_1_TYPE" "Local or network access?"
    printvar "POSTGRESQL84_HOST_1_NETWORK" "IP-Address of host or network"
    printvar "POSTGRESQL84_HOST_1_USERAUTH" "Authentication"
    printvar "POSTGRESQL84_HOST_1_DATABASE" "Affected databases or 'all' for all"
    printvar "POSTGRESQL84_HOST_1_USER" "Affected users or 'all' for all"
    echo ""
    printvar "POSTGRESQL84_HOST_2_TYPE" "Local or network access?"
    printvar "POSTGRESQL84_HOST_2_NETWORK" "IP-Address of host or network"
    printvar "POSTGRESQL84_HOST_2_USERAUTH" "Authentication"
    printvar "POSTGRESQL84_HOST_2_DATABASE" "Affected databases or 'all' for all"
    printvar "POSTGRESQL84_HOST_2_USER" "Affected users or 'all' for all"

    idx=3
    while [ "$idx" -le "$POSTGRESQL84_HOST_N" ]
    do
       echo ""
       printvar "POSTGRESQL84_HOST_${idx}_TYPE" "Local or network access?"
       printvar "POSTGRESQL84_HOST_${idx}_NETWORK" "IP-Address of host or network"
       printvar "POSTGRESQL84_HOST_${idx}_USERAUTH" "Authentication"
       printvar "POSTGRESQL84_HOST_${idx}_DATABASE" "Affected databases or 'all' for all"
       printvar "POSTGRESQL84_HOST_${idx}_USER" "Affected users or 'all' for all"
       idx=$(($idx + 1))
    done

    printgroup "Database backup"
    printvar "POSTGRESQL84_BACKUP_SCHEDULE" "Cron schedule for autom. backup"
    printvar "POSTGRESQL84_BACKUP_TARGET" "Target directory for backups"
    echo ""
    printvar "POSTGRESQL84_BACKUP_N" "Number of databases to backup"
    printvar "POSTGRESQL84_BACKUP_1_DBNAME" "Name of database to backup"
    printvar "POSTGRESQL84_BACKUP_1_USER" "User to connect to db server"
    printvar "POSTGRESQL84_BACKUP_1_MAX" "Number of backup files to maintain"
    idx=2
    while [ "$idx" -le "$POSTGRESQL84_BACKUP_N" ]
    do
       echo ""
       printvar "POSTGRESQL84_BACKUP_${idx}_DBNAME" "Name of database to backup"
       printvar "POSTGRESQL84_BACKUP_${idx}_USER" "User to connect to db server"
       printvar "POSTGRESQL84_BACKUP_${idx}_MAX" "Number of backup files to maintain"
       idx=$(($idx + 1))
    done
    echo ""
    printvar "POSTGRESQL84_BACKUP_MOUNT" "Command executed before backup"
    printvar "POSTGRESQL84_BACKUP_UMOUNT" "Command executed after backup"
    printvar "POSTGRESQL84_BACKUP_NOTIFY" "E-mail address for error notification"

    printgroup "Automatic database optimization"
    printvar "POSTGRESQL84_AUTOVACUUM" "Start autovacuum process"

    printgroup "Resource consumtion options (advanced)"
    printvar "POSTGRESQL84_RESOURCE_TUNING" "Manually overwrite default settings?"
    printvar "POSTGRESQL84_SHARED_MEM" "Size of shared memory block"
    printvar "POSTGRESQL84_TEMP_MEM" "Size of temporary memory"
    printvar "POSTGRESQL84_WORK_MEM" "Size of per session memory"
    printvar "POSTGRESQL84_MAINTAIN_MEM" "Size for maintainance tasks"
    printvar "POSTGRESQL84_PREP_TRANSACTIONS" "Max. number of prepared transact."

    printgroup "Write ahead log (WAL) options (advanced)"
    printvar "POSTGRESQL84_WAL_TUNING" "Manually overwrite default settings?"
    printvar "POSTGRESQL84_FSYNC" "Switch fsync on or off"
    printvar "POSTGRESQL84_SYNC_METHOD" "fsync, fdatasync, open_sync, open_datasync"
    printvar "POSTGRESQL84_WAL_DATA_MEM" "the amount of memory used for WAL data"
    printvar "POSTGRESQL84_COMMIT_DELAY" "Delay for writes on commits"
    printvar "POSTGRESQL84_COMMIT_SIBLINGS" "Number of concurrent commits to delay"
    printvar "POSTGRESQL84_CHECKPOINT_SECTIONS" "Number of sections before checkpoint"
    printvar "POSTGRESQL84_CHECKPOINT_TIMEOUT" "Timeout before checkpoint"
    printvar "POSTGRESQL84_CHECKPOINT_WARNING" "Min. time between checkpoints"

    printgroup "Log options (advanced)"
    printvar "POSTGRESQL84_LOG_SETTINGS" "manually overwrite default settings?"
    printvar "POSTGRESQL84_CLIENT_LOG_LEVEL" "Log level for client programs"
    printvar "POSTGRESQL84_SERVER_LOG_LEVEL" "log level for server log"
    printvar "POSTGRESQL84_LOG_VERBOSE" "Verbose log messages"
    printvar "POSTGRESQL84_LOG_STATEMENTS" "write SQL statements to log"

    printend
    ) > ${internal_conf_file}
    # Set rights
    chmod 0644 ${internal_conf_file}
    chown root ${internal_conf_file}
}

#----------------------------------------------------------------------------
# Create the check.d file
#----------------------------------------------------------------------------

make_check_file()
{
    (
    printgpl -check "$packages_name" "2007-03-03" "dv" \
         "2018 the eisfair team, team(at)eisfair(dot)org"
    echo "START_POSTGRESQL84                -                     -                     YESNO"
    echo "POSTGRESQL84_NETWORKING           START_POSTGRESQL84    -                     YESNO"
    echo "POSTGRESQL84_SERVER_PORT          START_POSTGRESQL84    -                     PORT"
    echo "POSTGRESQL84_MAX_CONNECTS         START_POSTGRESQL84    -                     NUMERIC"
    echo "POSTGRESQL84_MAX_CONNECTS         START_POSTGRESQL84    -                     PG84_MAXCONN"
    echo "POSTGRESQL84_HOST_N               START_POSTGRESQL84    -                     NUMERIC"
    echo "POSTGRESQL84_HOST_%_TYPE          START_POSTGRESQL84    POSTGRESQL84_HOST_N   PG84_ACCESSTYPE"
    echo "POSTGRESQL84_HOST_%_NETWORK       START_POSTGRESQL84    POSTGRESQL84_HOST_N   PG84_NETWORK"
    echo "POSTGRESQL84_HOST_%_USERAUTH      START_POSTGRESQL84    POSTGRESQL84_HOST_N   PG84_AUTHENTICATION"
    echo "POSTGRESQL84_HOST_%_DATABASE      START_POSTGRESQL84    POSTGRESQL84_HOST_N   NOTEMPTY"
    echo "POSTGRESQL84_HOST_%_USER          START_POSTGRESQL84    POSTGRESQL84_HOST_N   NOTEMPTY"

    echo "POSTGRESQL84_AUTOVACUUM           START_POSTGRESQL84    -                     YESNO"

    echo "POSTGRESQL84_RESOURCE_TUNING      START_POSTGRESQL84            -             YESNO"
    echo "POSTGRESQL84_SHARED_MEM           POSTGRESQL84_RESOURCE_TUNING  -             PG84_BYTENUM"
    echo "POSTGRESQL84_TEMP_MEM             POSTGRESQL84_RESOURCE_TUNING  -             PG84_BYTENUM"
    echo "POSTGRESQL84_WORK_MEM             POSTGRESQL84_RESOURCE_TUNING  -             PG84_BYTENUM"
    echo "POSTGRESQL84_MAINTAIN_MEM         POSTGRESQL84_RESOURCE_TUNING  -             PG84_BYTENUM"
    echo "POSTGRESQL84_PREP_TRANSACTIONS    POSTGRESQL84_RESOURCE_TUNING  -             NUMERIC"

    echo "POSTGRESQL84_WAL_TUNING           START_POSTGRESQL84            -             YESNO"
    echo "POSTGRESQL84_FSYNC                POSTGRESQL84_WAL_TUNING       -             YESNO"
    echo "POSTGRESQL84_SYNC_METHOD          POSTGRESQL84_WAL_TUNING       -             PG84_SYNCMETHOD"
    echo "POSTGRESQL84_WAL_DATA_MEM         POSTGRESQL84_WAL_TUNING       -             PG84_BYTENUM"
    echo "POSTGRESQL84_COMMIT_DELAY         POSTGRESQL84_WAL_TUNING       -             NUMERIC"
    echo "POSTGRESQL84_COMMIT_SIBLINGS      POSTGRESQL84_WAL_TUNING       -             NUMERIC"
    echo "POSTGRESQL84_CHECKPOINT_SECTIONS  POSTGRESQL84_WAL_TUNING       -             NUMERIC"
    echo "POSTGRESQL84_CHECKPOINT_TIMEOUT   POSTGRESQL84_WAL_TUNING       -             NUMERIC"
    echo "POSTGRESQL84_CHECKPOINT_WARNING   POSTGRESQL84_WAL_TUNING       -             NUMERIC"

    echo "POSTGRESQL84_LOG_SETTINGS         START_POSTGRESQL84            -             YESNO"
    echo "POSTGRESQL84_CLIENT_LOG_LEVEL     POSTGRESQL84_LOG_SETTINGS     -             PG84_LOGLEVEL"
    echo "POSTGRESQL84_SERVER_LOG_LEVEL     POSTGRESQL84_LOG_SETTINGS     -             PG84_LOGLEVEL"
    echo "POSTGRESQL84_LOG_VERBOSE          POSTGRESQL84_LOG_SETTINGS     -             YESNO"
    echo "POSTGRESQL84_LOG_STATEMENTS       POSTGRESQL84_LOG_SETTINGS     -             YESNO"

    echo "POSTGRESQL84_BACKUP_SCHEDULE      START_POSTGRESQL84    -                   CRONTAB"
    echo "POSTGRESQL84_BACKUP_TARGET        START_POSTGRESQL84    -                   ABS_PATH"
    echo "POSTGRESQL84_BACKUP_N             START_POSTGRESQL84    -                   NUMERIC"
    echo "POSTGRESQL84_BACKUP_%_DBNAME      START_POSTGRESQL84    POSTGRESQL84_BACKUP_N NOTEMPTY"
    echo "POSTGRESQL84_BACKUP_%_USER        START_POSTGRESQL84    POSTGRESQL84_BACKUP_N NOTEMPTY"
    echo "POSTGRESQL84_BACKUP_%_MAX         START_POSTGRESQL84    POSTGRESQL84_BACKUP_N NUMERIC"
    echo "POSTGRESQL84_BACKUP_MOUNT         START_POSTGRESQL84    -                   NONE"
    echo "POSTGRESQL84_BACKUP_UMOUNT        START_POSTGRESQL84    -                   NONE"
    echo "POSTGRESQL84_BACKUP_NOTIFY        START_POSTGRESQL84    -                   EMAILADDR"

    echo ""
    ) > /etc/check.d/${package}
    # Set rights for check.d file
    chmod 0644 /etc/check.d/${package}
    chown root /etc/check.d/${package}

    (
    printgpl -check_exp "$packages_name" "2009-04-26" "dv" \
         "2018 the eisfair team, team(at)eisfair(dot)org"
    echo "PG84_ACCESSTYPE         = 'local|host'"
    echo "                      : 'Wrong access type! Only \"local\" or \"host\" are"
    echo "                         allowed'"
    echo "PG84_NETWORK            = '()|(RE:NETWORK)'"
    echo "                      : 'no valid network specification, should be a network"
    echo "                         address followed by a netmask, for instance 192.168.6.0/24'"
    echo "PG84_AUTHENTICATION     = 'trust|reject|md5|crypt|password|krb4|krb5|ident|pam'"
    echo "                      : 'Wrong authentication method! Only \"trust\", \"reject\","
    echo "                         \"md5\", \"crypt\", \"password\", \"krb4\", \"krb5\","
    echo "                         \"ident\" or \"pam\" are allowed.'"
    echo "PG84_SYNCMETHOD         = 'fsync|fdatasync'"
    echo "                      : 'Wrong sync method! Only \"fsync\", \"fdatasync\".'"
    echo "PG84_LOGLEVEL           = 'debug5|debug4|debug3|debug2|debug1|log|notice|warning|error|fatal|panic'"
    echo "                      : 'Wrong loglevel! Only \"debug5\", \"debug4\", \"debug3\","
    echo "                         \"debug2\",\"debug1\", \"log\", \"notice\", \"warning\","
    echo "                         \"error\", \"fatal\", \"panic\" are allowed.'"
    echo "PG84_BYTENUM            = '(RE:NUMERIC)(GB|MB|kB|())'"
    echo "                      : 'Wrong memory size given! Use number with optional postfix "
    echo "                         \"GB\", \"MB\" or \"kB\".'"
    echo "PG84_MAXCONN            = '[1-9][0-9]{0,2}|[1][0-9]{3}|2000'"
    echo "                      : 'value must be in range 1..2000'"
    echo ""
    ) > /etc/check.d/${package}.exp
    # Set rights for check.exp file
    chmod 0644 /etc/check.d/${package}.exp
    chown root /etc/check.d/${package}.exp

    (
    printgpl -check_ext "$packages_name" "2009-04-26" "dv" \
         "2018 the eisfair team, team(at)eisfair(dot)org"
    echo "if (POSTGRESQL84_RESOURCE_TUNING)"
    echo "then"
    echo "    # first we have to calculate real memory sizes from configuration"
    echo "    # values. This is done in a for index = 1 to 4 loop..."
    echo ""
    echo "    # prepare loop"
    echo "    set enumstr = \"1 2 3 4\""
    echo "    split (enumstr, enum_%, ' ')"
    echo ""
    echo "    # run loop"
    echo "    foreach index in enum_%"
    echo "    do"
    echo "        # initialize loop parameter"
    echo "        if (index == 1)"
    echo "        then"
    echo "            set memsizestr = POSTGRESQL84_SHARED_MEM"
    echo "            set multiplyer = 8"
    echo "        fi"
    echo "        if (index == 2)"
    echo "        then"
    echo "            set memsizestr = POSTGRESQL84_TEMP_MEM"
    echo "            set multiplyer = 8"
    echo "        fi"
    echo "        if (index == 3)"
    echo "        then"
    echo "            set memsizestr = POSTGRESQL84_WORK_MEM"
    echo "            set multiplyer = 1"
    echo "        fi"
    echo "        if (index == 4)"
    echo "        then"
    echo "            set memsizestr = POSTGRESQL84_MAINTAIN_MEM"
    echo "            set multiplyer = 1"
    echo "        fi"
    echo ""
    echo "        set memsize = 0"
    echo ""
    echo "        # split string and calculate result"
    echo "        split (memsizestr, test_%, 'G')"
    echo "        if (test_%[1] == memsizestr)"
    echo "        then"
    echo ""
    echo "            split (memsizestr, test_%, 'M')"
    echo "            if (test_%[1] == memsizestr)"
    echo "            then"
    echo ""
    echo "                split (memsizestr, test_%, 'k')"
    echo "                if (test_%[1] == memsizestr)"
    echo "                then"
    echo "                    split (memsizestr, test2_%, ' ', numeric)"
    echo "                    set memsize = (test2_%[1] * multiplyer)"
    echo "                else"
    echo "                    split (memsizestr, test2_%, 'k', numeric)"
    echo "                    set memsize = test2_%[1]"
    echo "                fi"
    echo ""
    echo "            else"
    echo "                split (memsizestr, test2_%, 'M', numeric)"
    echo "                set memsize = (test2_%[1] * 1024)"
    echo "            fi"
    echo ""
    echo "        else"
    echo "            split (memsizestr, test2_%, 'G', numeric)"
    echo "            set memsize = (test2_%[1] * 1024 * 1024)"
    echo "        fi"
    echo ""
    echo "        # assign result"
    echo "        if (index == 1)"
    echo "        then"
    echo "            set shared_mem = memsize"
    echo "        fi"
    echo "        if (index == 2)"
    echo "        then"
    echo "            set temp_mem = memsize"
    echo "        fi"
    echo "        if (index == 3)"
    echo "        then"
    echo "            set work_mem = memsize"
    echo "        fi"
    echo "        if (index == 4)"
    echo "        then"
    echo "            set maintain_mem = memsize"
    echo "        fi"
    echo "    done"
    echo ""
    echo "    # now we can check if memory sizes are out of bounds:"
    echo ""
    echo "    # check shared buffers to be larger then 128 kByte and larger then"
    echo "    # max_connections * 16"
    echo "    if ((shared_mem < 128) || (shared_mem < POSTGRESQL84_MAX_CONNECTS * 16))"
    echo "    then"
    echo "        set required = POSTGRESQL84_MAX_CONNECTS * 16"
    echo "        if (required < 128)"
    echo "        then"
    echo "            set required = 128"
    echo "        fi"
    echo "        error \"POSTGRESQL84_SHARED_MEM to small! Abs. minimum is \${required}kB\""
    echo "    fi"
    echo "    if (shared_mem > 8589934584)"
    echo "    then"
    echo "        error \"POSTGRESQL84_SHARED_MEM is outside of max. valid range (8192GB)\""
    echo "    fi"
    echo ""
    echo "    # check if temp_mem is in valid range (not sure about the upper limit)"
    echo "    if ((temp_mem < 800) || (temp_mem > 8589934584))"
    echo "    then"
    echo "        error \"POSTGRESQL84_TEMP_MEM is outside of max. valid range (800KB .. 8192GB)\""
    echo "    fi"
    echo ""
    echo "    # check if work_mem is in valid range (not sure about the upper limit)"
    echo "    if ((work_mem < 64) || (work_mem > 2097151))"
    echo "    then"
    echo "        error \"POSTGRESQL84_WORK_MEM is outside of valid range (64KB .. 2GB)\""
    echo "    fi"
    echo ""
    echo "    # check if maintain_mem is in valid range (not sure about the upper limit)"
    echo "    if ((maintain_mem < 1024) || (maintain_mem > 2097151))"
    echo "    then"
    echo "        error \"POSTGRESQL84_MAINTAIN_MEM is outside of valid range (1MB .. 2GB)\""
    echo "    fi"
    echo ""
    echo "    # check if shared_buffers has a reasonable value (the limit is only an estimated"
    echo "    # one - only used to prevent the user from stating senseless values)"
    echo "    if (shared_mem > (1024 * 1024))"
    echo "    then"
    echo "        warning \"POSTGRESQL84_SHARED_MEM seems very large. Please note that up to 10% of the physical memory is a reasonalble value.\""
    echo "    fi"
    echo ""
    echo "    # check if work_mem has a reasonable value (the limit is only an estimated"
    echo "    # one - only used to prevent the user from stating senseless values)"
    echo "    if (work_mem > (64 * 1024))"
    echo "    then"
    echo "        warning \"POSTGRESQL84_WORK_MEM seems very large. For parallel sessions or complex queries this memory may be required many times.\""
    echo "    fi"
    echo "fi"
    echo ""
    echo "if (POSTGRESQL84_WAL_TUNING)"
    echo "then"
    echo "    set memsizestr = POSTGRESQL84_WAL_DATA_MEM"
    echo "    set multiplyer = 8"
    echo ""
    echo "    set memsize = 0"
    echo ""
    echo "    # split string and calculate result"
    echo "    split (memsizestr, test_%, 'G')"
    echo "    if (test_%[1] == memsizestr)"
    echo "    then"
    echo ""
    echo "        split (memsizestr, test_%, 'M')"
    echo "        if (test_%[1] == memsizestr)"
    echo "        then"
    echo ""
    echo "            split (memsizestr, test_%, 'k')"
    echo "            if (test_%[1] == memsizestr)"
    echo "            then"
    echo "                split (memsizestr, test2_%, ' ', numeric)"
    echo "                set memsize = (test2_%[1] * multiplyer)"
    echo "            else"
    echo "                split (memsizestr, test2_%, 'k', numeric)"
    echo "                set memsize = test2_%[1]"
    echo "            fi"
    echo ""
    echo "        else"
    echo "            split (memsizestr, test2_%, 'M', numeric)"
    echo "            set memsize = (test2_%[1] * 1024)"
    echo "        fi"
    echo ""
    echo "    else"
    echo "        split (memsizestr, test2_%, 'G', numeric)"
    echo "        set memsize = (test2_%[1] * 1024 * 1024)"
    echo "    fi"
    echo ""
    echo "    set wal_buffers = memsize"
    echo ""
    echo "    # check if wal_buffers is in valid range (not sure about the upper limit)"
    echo "    if ((wal_buffers < 32) || (wal_buffers > 17179869176))"
    echo "    then"
    echo "        error \"POSTGRESQL84_WAL_DATA_MEM is outside of valid range (32kB .. 16GB)\""
    echo "    fi"
    echo "fi"
    echo ""
    ) > /etc/check.d/${package}.ext
    # Set rights for check.exp file
    chmod 0644 /etc/check.d/${package}.ext
    chown root /etc/check.d/${package}.ext
}

#------------------------------------------------------------------------------
# Main
#------------------------------------------------------------------------------

# write default config file
make_config_file /etc/default.d/${package}

# update from old version
rename_old_variables
add_new_variables

# write new config file
make_config_file /etc/config.d/${package}

# write check.d file
make_check_file

#------------------------------------------------------------------------------
# End
#------------------------------------------------------------------------------
exit 0

